[−][src]Struct rust_webvr::vr_display_capabilities::VRDisplayCapabilities
describes the capabilities of a VRDisplay. These are expected to be static per-device/per-user.
Fields
has_position: booltrue if the VRDisplay is capable of tracking its position.
has_orientation: booltrue if the VRDisplay is capable of tracking its orientation.
has_external_display: booltrue if the VRDisplay is separate from the device’s primary display
can_present: booltrue if the VRDisplay is capable of presenting content to an HMD or similar device.
presented_by_browser: boolplease use future_frame_data instead
true if the VR display expects the browser to present the content.
This is now deprecated, a better solution is to implement future_frame_data
and have the future resolve when the next animation frame is ready.
max_layers: u64Indicates the maximum length of the array that requestPresent() will accept, Must be 1 if canPresent is true, 0 otherwise.