[−][src]Struct rust_webvr::vr_eye_parameters::VREyeParameters
The VREyeParameters interface represents all the information required to correctly render a scene for a given eye.
Fields
offset: [f32; 3]Offset from the center point between the users eyes to the center of the eye in meters.
render_width: u32Describes the recommended render target width of each eye viewport, in pixels.
render_height: u32Describes the recommended render target height of each eye viewport, in pixels.
field_of_view: VRFieldOfViewDescribes the current field of view for the eye