[][src]Struct rust_webvr::vr_layer::VRLayer

pub struct VRLayer {
    pub texture_id: u32,
    pub left_bounds: [f32; 4],
    pub right_bounds: [f32; 4],
    pub texture_size: Option<(u32, u32)>,
}

Data provided to a VRDisplay and presented in the HMD.

Fields

texture_id: u32

Source texture whose contents will be presented by the VRDisplay when VRDisplay.submitFrame() is called.

left_bounds: [f32; 4]

UVs defining the texture bounds to present to the eye in UV space: [x,y,w,h] Defaults to [0.0, 0.0, 0.5, 1.0]

right_bounds: [f32; 4]

UVs defining the texture bounds to present to the eye in UV space: [x,y,w,h] Defaults to [0.5, 0.0, 0.5, 1.0]

texture_size: Option<(u32, u32)>

Hint with texture size