[][src]Struct rust_webvr::vr_pose::VRPose

pub struct VRPose {
    pub position: Option<[f32; 3]>,
    pub linear_velocity: Option<[f32; 3]>,
    pub linear_acceleration: Option<[f32; 3]>,
    pub orientation: Option<[f32; 4]>,
    pub angular_velocity: Option<[f32; 3]>,
    pub angular_acceleration: Option<[f32; 3]>,
}

The VRPose struct represents a sensor’s state at a given timestamp.

Fields

position: Option<[f32; 3]>

Position of the VRDisplay as a 3D vector. May be None if the sensor is incapable of providing positional data.

linear_velocity: Option<[f32; 3]>

Linear velocity of the sensor given in meters per second. May be None if the sensor is incapable of providing linear velocity data.

linear_acceleration: Option<[f32; 3]>

Linear acceleration of the sensor given in meters per second squared. May be None if the sensor is incapable of providing linear acceleration data.

orientation: Option<[f32; 4]>

Orientation of the sensor as a quaternion. May be None if the sensor is incapable of providing orientation.

angular_velocity: Option<[f32; 3]>

Angular velocity of the sensor given in radians per second. May be None if the sensor is incapable of providing angular velocity data.

angular_acceleration: Option<[f32; 3]>

Linear acceleration of the sensor given in radians per second squared. May be None if the sensor is incapable of providing angular acceleration data.